@@ -3,14 +3,12 @@ import { Op, QueryTypes } from 'sequelize';
 import _config from 'config';
 
 import { SYNC_DIRECTIONS, DEBUG_LOG_TYPES, SETTINGS_SCOPES } from '@tamanu/constants';
-import {
-  CURRENT_SYNC_TIME_KEY,
-  LOOKUP_UP_TO_TICK_KEY,
-  SYNC_LOOKUP_PENDING_UPDATE_FLAG,
-} from '@tamanu/shared/sync/constants';
+import { FACT_CURRENT_SYNC_TICK, FACT_LOOKUP_UP_TO_TICK } from '@tamanu/constants/facts';
 import { log } from '@tamanu/shared/services/logging';
 import {
   adjustDataPostSyncPush,
+  bumpSyncTickForRepull,
+  incomingSyncHook,
   completeSyncSession,
   countSyncSnapshotRecords,
   createSnapshotTable,
@@ -23,7 +21,9 @@ import {
   SYNC_SESSION_DIRECTION,
   updateSnapshotRecords,
   waitForPendingEditsUsingSyncTick,
-} from '@tamanu/shared/sync';
+  SYNC_LOOKUP_PENDING_UPDATE_FLAG,
+  repeatableReadTransaction,
+} from '@tamanu/database/sync';
 import { uuidToFairlyUniqueInteger } from '@tamanu/shared/utils';
 
 import { getPatientLinkedModels } from './getPatientLinkedModels';
@@ -32,9 +32,8 @@ import { filterModelsFromName } from './filterModelsFromName';
 import { startSnapshotWhenCapacityAvailable } from './startSnapshotWhenCapacityAvailable';
 import { createMarkedForSyncPatientsTable } from './createMarkedForSyncPatientsTable';
 import { updateLookupTable, updateSyncLookupPendingRecords } from './updateLookupTable';
-import { repeatableReadTransaction } from './repeatableReadTransaction';
 
-const errorMessageFromSession = session =>
+const errorMessageFromSession = (session) =>
   `Sync session '${session.id}' encountered an error: ${session.errors[session.errors.length - 1]}`;
 
 // about variables lapsedSessionSeconds and lapsedSessionCheckFrequencySeconds:
@@ -81,7 +80,7 @@ export class CentralSyncManager {
     // "tick" part to be unique to the requesting client, and any changes made directly on the
     // central server will be recorded as updated at the "tock", avoiding any direct changes
     // (e.g. imports) being missed by a client that is at the same sync tick
-    const tock = await this.store.models.LocalSystemFact.increment(CURRENT_SYNC_TIME_KEY, 2);
+    const tock = await this.store.models.LocalSystemFact.incrementValue(FACT_CURRENT_SYNC_TICK, 2);
     return { tick: tock - 1, tock };
   }
 
@@ -253,13 +252,13 @@ export class CentralSyncManager {
       await this.waitForPendingEdits(currentTick);
 
       const previouslyUpToTick =
-        (await store.models.LocalSystemFact.get(LOOKUP_UP_TO_TICK_KEY)) || -1;
+        (await store.models.LocalSystemFact.get(FACT_LOOKUP_UP_TO_TICK)) || -1;
 
       await debugObject.addInfo({ since: previouslyUpToTick });
 
       const isInitialBuildOfLookupTable = parseInt(previouslyUpToTick, 10) === -1;
 
-      await repeatableReadTransaction(store.sequelize, async transaction => {
+      await repeatableReadTransaction(store.sequelize, async (transaction) => {
         // do not need to update pending records when it is initial build
         // because it uses ticks from the actual tables for updated_at_sync_tick
         if (!isInitialBuildOfLookupTable) {
@@ -294,7 +293,7 @@ export class CentralSyncManager {
         log.debug('CentralSyncManager.updateLookupTable()', {
           lastSuccessfulLookupTableUpdate: currentTick,
         });
-        await store.models.LocalSystemFact.set(LOOKUP_UP_TO_TICK_KEY, currentTick);
+        await store.models.LocalSystemFact.set(FACT_LOOKUP_UP_TO_TICK, currentTick);
       });
     } catch (error) {
       log.error('CentralSyncManager.updateLookupTable encountered an error', {
@@ -316,13 +315,13 @@ export class CentralSyncManager {
   async waitForPendingEdits(tick) {
     // get all the ticks (ie: keys of in-flight transaction advisory locks) of previously pending edits
     const pendingSyncTicks = (await getSyncTicksOfPendingEdits(this.store.sequelize)).filter(
-      t => t < tick,
+      (t) => t < tick,
     );
 
     // wait for any in-flight transactions of pending edits
     // that we don't miss any changes that are in progress
     await Promise.all(
-      pendingSyncTicks.map(t => waitForPendingEditsUsingSyncTick(this.store.sequelize, t)),
+      pendingSyncTicks.map((t) => waitForPendingEditsUsingSyncTick(this.store.sequelize, t)),
     );
   }
 
@@ -587,6 +586,11 @@ export class CentralSyncManager {
         // by an exclusive lock taken prior to starting a snapshot - so this is now purely for
         // saving with a unique tick
         const { tock } = await this.tickTockGlobalClock();
+
+        // run any side effects for each model
+        // eg: resolving duplicated patient display IDs
+        await incomingSyncHook(sequelize, modelsToInclude, sessionId);
+
         await saveIncomingChanges(sequelize, modelsToInclude, sessionId, true);
         // store the sync tick on save with the incoming changes, so they can be compared for
         // edits with the outgoing changes
@@ -609,6 +613,9 @@ export class CentralSyncManager {
       await this.tickTockGlobalClock();
       await adjustDataPostSyncPush(sequelize, modelsToInclude, sessionId);
 
+      // mark for repull any records that were modified by an incoming sync hook
+      await bumpSyncTickForRepull(sequelize, modelsToInclude, sessionId);
+
       // mark persisted so that client polling "completePush" can stop
       await models.SyncSession.update(
         { persistCompletedAt: new Date() },
@@ -626,7 +633,7 @@ export class CentralSyncManager {
   async addIncomingChanges(sessionId, changes) {
     const { sequelize } = this.store;
     await this.connectToSession(sessionId);
-    const incomingSnapshotRecords = changes.map(c => ({
+    const incomingSnapshotRecords = changes.map((c) => ({
       ...c,
       direction: SYNC_SESSION_DIRECTION.INCOMING,
       updatedAtByFieldSum: c.data.updatedAtByField
