@@ -23,6 +23,8 @@ import { PatientTelegramCommunicationProcessor } from './PatientTelegramCommunic
 import { VaccinationReminderProcessor } from './VaccinationReminderProcessor';
 import { SurveyCompletionNotifierProcessor } from './SurveyCompletionNotifierProcessor';
 import { SyncLookupRefresher } from './SyncLookupRefresher';
+import { GenerateRepeatingTasks } from './GenerateRepeatingTasks';
+import { GenerateRepeatingAppointments } from './GenerateRepeatingAppointments';
 
 export { startFhirWorkerTasks } from './fhir';
 
@@ -44,6 +46,8 @@ export async function startScheduledTasks(context) {
     FhirMissingResources,
     SurveyCompletionNotifierProcessor,
     SyncLookupRefresher,
+    GenerateRepeatingTasks,
+    GenerateRepeatingAppointments,
   ];
 
   if (config.integrations.fijiVrs.enabled) {
@@ -55,7 +59,7 @@ export async function startScheduledTasks(context) {
 
   const reportSchedulers = await getReportSchedulers(context);
   const tasks = [
-    ...taskClasses.map(TaskClass => {
+    ...taskClasses.map((TaskClass) => {
       try {
         log.debug(`Starting to initialise scheduled task ${TaskClass.name}`);
         return new TaskClass(context);
@@ -65,9 +69,9 @@ export async function startScheduledTasks(context) {
       }
     }),
     ...reportSchedulers,
-  ].filter(x => x);
-  tasks.forEach(t => t.beginPolling());
-  return () => tasks.forEach(t => t.cancelPolling());
+  ].filter((x) => x);
+  tasks.forEach((t) => t.beginPolling());
+  return () => tasks.forEach((t) => t.cancelPolling());
 }
 
 async function getReportSchedulers(context) {
